# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from openapi_evm_api import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401

from openapi_evm_api.model.chain_list import ChainList
from openapi_evm_api.model.log_event import LogEvent

from . import path

# Query params
ChainSchema = ChainList


class FromBlockSchema(
    schemas.IntSchema
):


    class MetaOapg:
        inclusive_minimum = 0


class ToBlockSchema(
    schemas.IntSchema
):


    class MetaOapg:
        inclusive_minimum = 0
FromDateSchema = schemas.StrSchema
ToDateSchema = schemas.StrSchema
TopicSchema = schemas.StrSchema


class OffsetSchema(
    schemas.IntSchema
):


    class MetaOapg:
        inclusive_minimum = 0


class LimitSchema(
    schemas.IntSchema
):


    class MetaOapg:
        inclusive_minimum = 0
DisableTotalSchema = schemas.BoolSchema
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
        'topic': typing.Union[TopicSchema, str, ],
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'chain': typing.Union[ChainSchema, ],
        'from_block': typing.Union[FromBlockSchema, decimal.Decimal, int, ],
        'to_block': typing.Union[ToBlockSchema, decimal.Decimal, int, ],
        'from_date': typing.Union[FromDateSchema, str, ],
        'to_date': typing.Union[ToDateSchema, str, ],
        'offset': typing.Union[OffsetSchema, decimal.Decimal, int, ],
        'limit': typing.Union[LimitSchema, decimal.Decimal, int, ],
        'disable_total': typing.Union[DisableTotalSchema, bool, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_chain = api_client.QueryParameter(
    name="chain",
    style=api_client.ParameterStyle.FORM,
    schema=ChainSchema,
    explode=True,
)
request_query_from_block = api_client.QueryParameter(
    name="from_block",
    style=api_client.ParameterStyle.FORM,
    schema=FromBlockSchema,
    explode=True,
)
request_query_to_block = api_client.QueryParameter(
    name="to_block",
    style=api_client.ParameterStyle.FORM,
    schema=ToBlockSchema,
    explode=True,
)
request_query_from_date = api_client.QueryParameter(
    name="from_date",
    style=api_client.ParameterStyle.FORM,
    schema=FromDateSchema,
    explode=True,
)
request_query_to_date = api_client.QueryParameter(
    name="to_date",
    style=api_client.ParameterStyle.FORM,
    schema=ToDateSchema,
    explode=True,
)
request_query_topic = api_client.QueryParameter(
    name="topic",
    style=api_client.ParameterStyle.FORM,
    schema=TopicSchema,
    required=True,
    explode=True,
)
request_query_offset = api_client.QueryParameter(
    name="offset",
    style=api_client.ParameterStyle.FORM,
    schema=OffsetSchema,
    explode=True,
)
request_query_limit = api_client.QueryParameter(
    name="limit",
    style=api_client.ParameterStyle.FORM,
    schema=LimitSchema,
    explode=True,
)
request_query_disable_total = api_client.QueryParameter(
    name="disable_total",
    style=api_client.ParameterStyle.FORM,
    schema=DisableTotalSchema,
    explode=True,
)
# Path params
AddressSchema = schemas.StrSchema
RequestRequiredPathParams = typing_extensions.TypedDict(
    'RequestRequiredPathParams',
    {
        'address': typing.Union[AddressSchema, str, ],
    }
)
RequestOptionalPathParams = typing_extensions.TypedDict(
    'RequestOptionalPathParams',
    {
    },
    total=False
)


class RequestPathParams(RequestRequiredPathParams, RequestOptionalPathParams):
    pass


request_path_address = api_client.PathParameter(
    name="address",
    style=api_client.ParameterStyle.SIMPLE,
    schema=AddressSchema,
    required=True,
)
# body param
SchemaForRequestBodyApplicationJson = schemas.DictSchema


request_body_body = api_client.RequestBody(
    content={
        'application/json': api_client.MediaType(
            schema=SchemaForRequestBodyApplicationJson),
    },
    required=True,
)
_auth = [
    'ApiKeyAuth',
]


class SchemaFor200ResponseBodyApplicationJson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
            total = schemas.IntSchema
            page = schemas.IntSchema
            page_size = schemas.IntSchema
            
            
            class result(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['LogEvent']:
                        return LogEvent
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['LogEvent'], typing.List['LogEvent']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'result':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'LogEvent':
                    return super().__getitem__(i)
            __annotations__ = {
                "total": total,
                "page": page,
                "page_size": page_size,
                "result": result,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["total"]) -> MetaOapg.properties.total: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["page"]) -> MetaOapg.properties.page: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["page_size"]) -> MetaOapg.properties.page_size: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["result"]) -> MetaOapg.properties.result: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["total", "page", "page_size", "result", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["total"]) -> typing.Union[MetaOapg.properties.total, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["page"]) -> typing.Union[MetaOapg.properties.page, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["page_size"]) -> typing.Union[MetaOapg.properties.page_size, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["result"]) -> typing.Union[MetaOapg.properties.result, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["total", "page", "page_size", "result", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        total: typing.Union[MetaOapg.properties.total, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        page: typing.Union[MetaOapg.properties.page, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        page_size: typing.Union[MetaOapg.properties.page_size, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        result: typing.Union[MetaOapg.properties.result, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaFor200ResponseBodyApplicationJson':
        return super().__new__(
            cls,
            *args,
            total=total,
            page=page,
            page_size=page_size,
            result=result,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)
_status_code_to_response = {
    '200': _response_for_200,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):
    @typing.overload
    def _get_contract_events_oapg(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,dict, frozendict.frozendict, ],
        content_type: typing_extensions.Literal["application/json"] = ...,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def _get_contract_events_oapg(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,dict, frozendict.frozendict, ],
        content_type: str = ...,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...


    @typing.overload
    def _get_contract_events_oapg(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,dict, frozendict.frozendict, ],
        skip_deserialization: typing_extensions.Literal[True],
        content_type: str = ...,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def _get_contract_events_oapg(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,dict, frozendict.frozendict, ],
        content_type: str = ...,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def _get_contract_events_oapg(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,dict, frozendict.frozendict, ],
        content_type: str = 'application/json',
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        """
        Get events by contract
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        self._verify_typed_dict_inputs_oapg(RequestPathParams, path_params)
        used_path = path.value

        _path_params = {}
        for parameter in (
            request_path_address,
        ):
            parameter_data = path_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            serialized_data = parameter.serialize(parameter_data)
            _path_params.update(serialized_data)

        for k, v in _path_params.items():
            used_path = used_path.replace('{%s}' % k, v)

        prefix_separator_iterator = None
        for parameter in (
            request_query_chain,
            request_query_from_block,
            request_query_to_block,
            request_query_from_date,
            request_query_to_date,
            request_query_topic,
            request_query_offset,
            request_query_limit,
            request_query_disable_total,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        if body is schemas.unset:
            raise exceptions.ApiValueError(
                'The required body parameter has an invalid value of: unset. Set a valid value instead')
        _fields = None
        _body = None
        serialized_data = request_body_body.serialize(body, content_type)
        _headers.add('Content-Type', content_type)
        if 'fields' in serialized_data:
            _fields = serialized_data['fields']
        elif 'body' in serialized_data:
            _body = serialized_data['body']
        response = self.api_client.call_api(
            resource_path=used_path,
            method='post'.upper(),
            headers=_headers,
            fields=_fields,
            body=_body,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(api_response=api_response)

        return api_response


class GetContractEvents(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    @typing.overload
    def get_contract_events(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,dict, frozendict.frozendict, ],
        content_type: typing_extensions.Literal["application/json"] = ...,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def get_contract_events(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,dict, frozendict.frozendict, ],
        content_type: str = ...,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...


    @typing.overload
    def get_contract_events(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,dict, frozendict.frozendict, ],
        skip_deserialization: typing_extensions.Literal[True],
        content_type: str = ...,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def get_contract_events(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,dict, frozendict.frozendict, ],
        content_type: str = ...,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def get_contract_events(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,dict, frozendict.frozendict, ],
        content_type: str = 'application/json',
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._get_contract_events_oapg(
            body=body,
            query_params=query_params,
            path_params=path_params,
            content_type=content_type,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForpost(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    @typing.overload
    def post(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,dict, frozendict.frozendict, ],
        content_type: typing_extensions.Literal["application/json"] = ...,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def post(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,dict, frozendict.frozendict, ],
        content_type: str = ...,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...


    @typing.overload
    def post(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,dict, frozendict.frozendict, ],
        skip_deserialization: typing_extensions.Literal[True],
        content_type: str = ...,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def post(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,dict, frozendict.frozendict, ],
        content_type: str = ...,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def post(
        self,
        body: typing.Union[SchemaForRequestBodyApplicationJson,dict, frozendict.frozendict, ],
        content_type: str = 'application/json',
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._get_contract_events_oapg(
            body=body,
            query_params=query_params,
            path_params=path_params,
            content_type=content_type,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class Erc20Burn(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "from_wallet",
            "block_timestamp",
            "block_hash",
            "block_number",
            "transaction_index",
            "contract_address",
            "log_index",
            "value",
            "transaction_hash",
        }
        
        class properties:
            contract_address = schemas.StrSchema
            transaction_hash = schemas.StrSchema
            transaction_index = schemas.IntSchema
            log_index = schemas.IntSchema
            block_timestamp = schemas.StrSchema
            block_number = schemas.IntSchema
            block_hash = schemas.StrSchema
            from_wallet = schemas.StrSchema
            value = schemas.StrSchema
            __annotations__ = {
                "contract_address": contract_address,
                "transaction_hash": transaction_hash,
                "transaction_index": transaction_index,
                "log_index": log_index,
                "block_timestamp": block_timestamp,
                "block_number": block_number,
                "block_hash": block_hash,
                "from_wallet": from_wallet,
                "value": value,
            }

    
    from_wallet: MetaOapg.properties.from_wallet
    block_timestamp: MetaOapg.properties.block_timestamp
    block_hash: MetaOapg.properties.block_hash
    block_number: MetaOapg.properties.block_number
    transaction_index: MetaOapg.properties.transaction_index
    contract_address: MetaOapg.properties.contract_address
    log_index: MetaOapg.properties.log_index
    value: MetaOapg.properties.value
    transaction_hash: MetaOapg.properties.transaction_hash
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["contract_address"]) -> MetaOapg.properties.contract_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_hash"]) -> MetaOapg.properties.transaction_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_index"]) -> MetaOapg.properties.transaction_index: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["log_index"]) -> MetaOapg.properties.log_index: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_hash"]) -> MetaOapg.properties.block_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["from_wallet"]) -> MetaOapg.properties.from_wallet: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["contract_address", "transaction_hash", "transaction_index", "log_index", "block_timestamp", "block_number", "block_hash", "from_wallet", "value", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["contract_address"]) -> MetaOapg.properties.contract_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_hash"]) -> MetaOapg.properties.transaction_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_index"]) -> MetaOapg.properties.transaction_index: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["log_index"]) -> MetaOapg.properties.log_index: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_hash"]) -> MetaOapg.properties.block_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["from_wallet"]) -> MetaOapg.properties.from_wallet: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["contract_address", "transaction_hash", "transaction_index", "log_index", "block_timestamp", "block_number", "block_hash", "from_wallet", "value", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        from_wallet: typing.Union[MetaOapg.properties.from_wallet, str, ],
        block_timestamp: typing.Union[MetaOapg.properties.block_timestamp, str, ],
        block_hash: typing.Union[MetaOapg.properties.block_hash, str, ],
        block_number: typing.Union[MetaOapg.properties.block_number, decimal.Decimal, int, ],
        transaction_index: typing.Union[MetaOapg.properties.transaction_index, decimal.Decimal, int, ],
        contract_address: typing.Union[MetaOapg.properties.contract_address, str, ],
        log_index: typing.Union[MetaOapg.properties.log_index, decimal.Decimal, int, ],
        value: typing.Union[MetaOapg.properties.value, str, ],
        transaction_hash: typing.Union[MetaOapg.properties.transaction_hash, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Erc20Burn':
        return super().__new__(
            cls,
            *args,
            from_wallet=from_wallet,
            block_timestamp=block_timestamp,
            block_hash=block_hash,
            block_number=block_number,
            transaction_index=transaction_index,
            contract_address=contract_address,
            log_index=log_index,
            value=value,
            transaction_hash=transaction_hash,
            _configuration=_configuration,
            **kwargs,
        )



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from openapi_aptos_api.apis.tag_to_api import tag_to_api

import enum


class TagValues(str, enum.Enum):
    ACCOUNTS = "accounts"
    COINS = "coins"
    COLLECTIONS = "collections"
    DEFAULT = "default"
    NFTS = "nfts"
    TRANSACTIONS = "transactions"
    WALLETS = "wallets"



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class Erc20Price(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "usdPrice",
        }
        
        class properties:
            usdPrice = schemas.Float64Schema
        
            @staticmethod
            def nativePrice() -> typing.Type['NativeErc20Price']:
                return NativeErc20Price
            exchangeAddress = schemas.StrSchema
            exchangeName = schemas.StrSchema
            __annotations__ = {
                "usdPrice": usdPrice,
                "nativePrice": nativePrice,
                "exchangeAddress": exchangeAddress,
                "exchangeName": exchangeName,
            }

    
    usdPrice: MetaOapg.properties.usdPrice
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["usdPrice"]) -> MetaOapg.properties.usdPrice: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["nativePrice"]) -> 'NativeErc20Price': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["exchangeAddress"]) -> MetaOapg.properties.exchangeAddress: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["exchangeName"]) -> MetaOapg.properties.exchangeName: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["usdPrice", "nativePrice", "exchangeAddress", "exchangeName", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["usdPrice"]) -> MetaOapg.properties.usdPrice: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["nativePrice"]) -> typing.Union['NativeErc20Price', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["exchangeAddress"]) -> typing.Union[MetaOapg.properties.exchangeAddress, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["exchangeName"]) -> typing.Union[MetaOapg.properties.exchangeName, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["usdPrice", "nativePrice", "exchangeAddress", "exchangeName", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        usdPrice: typing.Union[MetaOapg.properties.usdPrice, decimal.Decimal, int, float, ],
        nativePrice: typing.Union['NativeErc20Price', schemas.Unset] = schemas.unset,
        exchangeAddress: typing.Union[MetaOapg.properties.exchangeAddress, str, schemas.Unset] = schemas.unset,
        exchangeName: typing.Union[MetaOapg.properties.exchangeName, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Erc20Price':
        return super().__new__(
            cls,
            *args,
            usdPrice=usdPrice,
            nativePrice=nativePrice,
            exchangeAddress=exchangeAddress,
            exchangeName=exchangeName,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_evm_api.model.native_erc20_price import NativeErc20Price



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class AptosNetwork(
    schemas.ListSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        
        class items(
            schemas.EnumBase,
            schemas.StrSchema
        ):
        
        
            class MetaOapg:
                enum_value_to_name = {
                    "mainnet": "MAINNET",
                    "testnet": "TESTNET",
                }
            
            @schemas.classproperty
            def MAINNET(cls):
                return cls("mainnet")
            
            @schemas.classproperty
            def TESTNET(cls):
                return cls("testnet")

    def __new__(
        cls,
        arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'AptosNetwork':
        return super().__new__(
            cls,
            arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> MetaOapg.items:
        return super().__getitem__(i)



from .request_challenge_aptos import request_challenge_aptos
from .request_challenge_evm import request_challenge_evm
from .request_challenge_solana import request_challenge_solana
from .verify_challenge_aptos import verify_challenge_aptos
from .verify_challenge_evm import verify_challenge_evm
from .verify_challenge_solana import verify_challenge_solana



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class DecodedEvent(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            signature = schemas.StrSchema
            label = schemas.StrSchema
            type = schemas.StrSchema
            
            
            class params(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    
                    class items(
                        schemas.DictSchema
                    ):
                    
                    
                        class MetaOapg:
                            
                            class properties:
                                name = schemas.StrSchema
                                value = schemas.StrSchema
                                type = schemas.StrSchema
                                __annotations__ = {
                                    "name": name,
                                    "value": value,
                                    "type": type,
                                }
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
                        
                        @typing.overload
                        def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                        
                        def __getitem__(self, name: typing.Union[typing_extensions.Literal["name", "value", "type", ], str]):
                            # dict_instance[name] accessor
                            return super().__getitem__(name)
                        
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> typing.Union[MetaOapg.properties.value, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> typing.Union[MetaOapg.properties.type, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                        
                        def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["name", "value", "type", ], str]):
                            return super().get_item_oapg(name)
                        
                    
                        def __new__(
                            cls,
                            *args: typing.Union[dict, frozendict.frozendict, ],
                            name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
                            value: typing.Union[MetaOapg.properties.value, str, schemas.Unset] = schemas.unset,
                            type: typing.Union[MetaOapg.properties.type, str, schemas.Unset] = schemas.unset,
                            _configuration: typing.Optional[schemas.Configuration] = None,
                            **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                        ) -> 'items':
                            return super().__new__(
                                cls,
                                *args,
                                name=name,
                                value=value,
                                type=type,
                                _configuration=_configuration,
                                **kwargs,
                            )
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'params':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            __annotations__ = {
                "signature": signature,
                "label": label,
                "type": type,
                "params": params,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["signature"]) -> MetaOapg.properties.signature: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["label"]) -> MetaOapg.properties.label: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["params"]) -> MetaOapg.properties.params: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["signature", "label", "type", "params", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["signature"]) -> typing.Union[MetaOapg.properties.signature, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["label"]) -> typing.Union[MetaOapg.properties.label, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> typing.Union[MetaOapg.properties.type, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["params"]) -> typing.Union[MetaOapg.properties.params, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["signature", "label", "type", "params", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        signature: typing.Union[MetaOapg.properties.signature, str, schemas.Unset] = schemas.unset,
        label: typing.Union[MetaOapg.properties.label, str, schemas.Unset] = schemas.unset,
        type: typing.Union[MetaOapg.properties.type, str, schemas.Unset] = schemas.unset,
        params: typing.Union[MetaOapg.properties.params, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'DecodedEvent':
        return super().__new__(
            cls,
            *args,
            signature=signature,
            label=label,
            type=type,
            params=params,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401


class ModuleStruct(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "abilities",
            "is_native",
            "generic_type_params",
            "name",
            "fields",
        }
        
        class properties:
            name = schemas.StrSchema
            is_native = schemas.BoolSchema
            
            
            class abilities(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'abilities':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            
            
            class generic_type_params(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['GenericTypeParam']:
                        return GenericTypeParam
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['GenericTypeParam'], typing.List['GenericTypeParam']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'generic_type_params':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'GenericTypeParam':
                    return super().__getitem__(i)
            
            
            class fields(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['ModuleStructField']:
                        return ModuleStructField
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['ModuleStructField'], typing.List['ModuleStructField']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'fields':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'ModuleStructField':
                    return super().__getitem__(i)
            __annotations__ = {
                "name": name,
                "is_native": is_native,
                "abilities": abilities,
                "generic_type_params": generic_type_params,
                "fields": fields,
            }
    
    abilities: MetaOapg.properties.abilities
    is_native: MetaOapg.properties.is_native
    generic_type_params: MetaOapg.properties.generic_type_params
    name: MetaOapg.properties.name
    fields: MetaOapg.properties.fields
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_native"]) -> MetaOapg.properties.is_native: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["abilities"]) -> MetaOapg.properties.abilities: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["generic_type_params"]) -> MetaOapg.properties.generic_type_params: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fields"]) -> MetaOapg.properties.fields: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["name", "is_native", "abilities", "generic_type_params", "fields", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_native"]) -> MetaOapg.properties.is_native: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["abilities"]) -> MetaOapg.properties.abilities: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["generic_type_params"]) -> MetaOapg.properties.generic_type_params: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fields"]) -> MetaOapg.properties.fields: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["name", "is_native", "abilities", "generic_type_params", "fields", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        abilities: typing.Union[MetaOapg.properties.abilities, list, tuple, ],
        is_native: typing.Union[MetaOapg.properties.is_native, bool, ],
        generic_type_params: typing.Union[MetaOapg.properties.generic_type_params, list, tuple, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        fields: typing.Union[MetaOapg.properties.fields, list, tuple, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ModuleStruct':
        return super().__new__(
            cls,
            *args,
            abilities=abilities,
            is_native=is_native,
            generic_type_params=generic_type_params,
            name=name,
            fields=fields,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_aptos_api.model.generic_type_param import GenericTypeParam
from openapi_aptos_api.model.module_struct_field import ModuleStructField



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from openapi_aptos_api.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    NFTS = "/nfts"
    NFTS_COLLECTIONS_COLLECTION_DATA_ID_HASH_TOKENS = "/nfts/collections/{collection_data_id_hash}/tokens"
    NFTS_CREATORS = "/nfts/creators"
    COLLECTIONS = "/collections"
    COLLECTIONS_IDS = "/collections/ids"
    COLLECTIONS_CREATORS = "/collections/creators"
    NFTS_OWNERS = "/nfts/owners"
    NFTS_COLLECTIONS_COLLECTION_DATA_ID_HASH_OWNERS = "/nfts/collections/{collection_data_id_hash}/owners"
    NFTS_COLLECTIONS_COLLECTION_DATA_ID_HASH_OWNERS_LIST = "/nfts/collections/{collection_data_id_hash}/owners/list"
    NFTS_TRANSFERS = "/nfts/transfers"
    NFTS_TRANSFERS_COLLECTIONS_COLLECTION_DATA_ID_HASH = "/nfts/transfers/collections/{collection_data_id_hash}"
    NFTS_TRANSFERS_CREATORS = "/nfts/transfers/creators"
    NFTS_TRANSFERS_WALLETS = "/nfts/transfers/wallets"
    COINS = "/coins"
    COINS_LATEST = "/coins/latest"
    COINS_NAMES = "/coins/names"
    COINS_SYMBOLS = "/coins/symbols"
    COINS_CREATORS = "/coins/creators"
    COINS_TRANSFERS_WALLETS = "/coins/transfers/wallets"
    COINS_TRANSFERS_BLOCKS = "/coins/transfers/blocks"
    COINS_TRANSFERS_COIN_TYPE = "/coins/transfers/{coin_type}"
    COINS_OWNERS_COIN_TYPE_HASH_TOPHOLDERS = "/coins/owners/{coin_type_hash}/top-holders"
    WALLETS_COINS = "/wallets/coins"
    WALLETS_COINS_HISTORY = "/wallets/coins/history"
    WALLETS_COINS_TRANSFERS = "/wallets/coins/transfers"
    WALLETS_NFTS = "/wallets/nfts"
    WALLETS_NFTS_TRANSFERS = "/wallets/nfts/transfers"
    ACCOUNTS_ADDRESS = "/accounts/{address}"
    ACCOUNTS_ADDRESS_RESOURCES = "/accounts/{address}/resources"
    ACCOUNTS_ADDRESS_MODULES = "/accounts/{address}/modules"
    ACCOUNTS_ADDRESS_RESOURCE_RESOURCE_TYPE = "/accounts/{address}/resource/{resource_type}"
    ACCOUNTS_ADDRESS_RESOURCE_MODULE_NAME = "/accounts/{address}/resource/{module_name}"
    ACCOUNTS_ADDRESS_EVENTS_CREATION_NUMBER = "/accounts/{address}/events/{creation_number}"
    ACCOUNTS_ADDRESS_EVENTS_EVENT_HANDLE_FIELD_NAME = "/accounts/{address}/events/{event_handle}/{field_name}"
    TRANSACTIONS = "/transactions"
    TRANSACTIONS_BY_HASH_TXN_HASH = "/transactions/by_hash/{txn_hash}"
    TRANSACTIONS_BY_VERSION_TXN_VERSION = "/transactions/by_version/{txn_version}"
    ACCOUNTS_ADDRESS_TRANSACTIONS = "/accounts/{address}/transactions"
    TRANSACTIONS_BATCH = "/transactions/batch"
    TRANSACTIONS_SIMULATE = "/transactions/simulate"
    TRANSACTIONS_ENCODE_SUBMISSION = "/transactions/encode_submission"
    TRANSACTIONS_ESTIMATE_GAS_PRICE = "/transactions/estimate_gas_price"
    BLOCKS_BLOCK_HEIGHT = "/blocks/{block_height}"
    BLOCKS_BY_VERSION_VERSION = "/blocks/by_version/{version}"



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class AptosCoinDeposit(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "sequenceNumber",
            "address",
            "valueWithDecimals",
            "value",
            "coin",
        }
        
        class properties:
            sequenceNumber = schemas.StrSchema
            valueWithDecimals = schemas.StrSchema
        
            @staticmethod
            def coin() -> typing.Type['AptosCoin']:
                return AptosCoin
            address = schemas.StrSchema
            value = schemas.StrSchema
            __annotations__ = {
                "sequenceNumber": sequenceNumber,
                "valueWithDecimals": valueWithDecimals,
                "coin": coin,
                "address": address,
                "value": value,
            }
    
    sequenceNumber: MetaOapg.properties.sequenceNumber
    address: MetaOapg.properties.address
    valueWithDecimals: MetaOapg.properties.valueWithDecimals
    value: MetaOapg.properties.value
    coin: 'AptosCoin'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sequenceNumber"]) -> MetaOapg.properties.sequenceNumber: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["valueWithDecimals"]) -> MetaOapg.properties.valueWithDecimals: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["coin"]) -> 'AptosCoin': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["sequenceNumber", "valueWithDecimals", "coin", "address", "value", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sequenceNumber"]) -> MetaOapg.properties.sequenceNumber: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["valueWithDecimals"]) -> MetaOapg.properties.valueWithDecimals: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["coin"]) -> 'AptosCoin': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["sequenceNumber", "valueWithDecimals", "coin", "address", "value", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        sequenceNumber: typing.Union[MetaOapg.properties.sequenceNumber, str, ],
        address: typing.Union[MetaOapg.properties.address, str, ],
        valueWithDecimals: typing.Union[MetaOapg.properties.valueWithDecimals, str, ],
        value: typing.Union[MetaOapg.properties.value, str, ],
        coin: 'AptosCoin',
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'AptosCoinDeposit':
        return super().__new__(
            cls,
            *args,
            sequenceNumber=sequenceNumber,
            address=address,
            valueWithDecimals=valueWithDecimals,
            value=value,
            coin=coin,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_streams.model.aptos_coin import AptosCoin



from .get_coin_balances_by_wallets import get_coin_balances_by_wallets
from .get_coin_transfers_by_wallet_addresses import get_coin_transfers_by_wallet_addresses
from .get_historical_coin_balances_by_wallets import get_historical_coin_balances_by_wallets
from .get_nft_by_owners import get_nft_by_owners
from .get_wallets_nft_transfers import get_wallets_nft_transfers



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401


class BlockMetadataTransaction(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "proposer",
            "event_root_hash",
            "gas_used",
            "changes",
            "previous_block_votes_bitvec",
            "state_checkpoint_hash",
            "epoch",
            "state_change_hash",
            "accumulator_root_hash",
            "type",
            "version",
            "failed_proposer_indices",
            "vm_status",
            "round",
            "success",
            "id",
            "events",
            "hash",
            "timestamp",
        }
        
        class properties:
            type = schemas.StrSchema
            version = schemas.StrSchema
            hash = schemas.StrSchema
            state_change_hash = schemas.StrSchema
            event_root_hash = schemas.StrSchema
            state_checkpoint_hash = schemas.StrSchema
            gas_used = schemas.StrSchema
            success = schemas.BoolSchema
            vm_status = schemas.StrSchema
            accumulator_root_hash = schemas.StrSchema
            
            
            class changes(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'changes':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            id = schemas.StrSchema
            epoch = schemas.StrSchema
            round = schemas.StrSchema
            
            
            class events(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['TransactionEvent']:
                        return TransactionEvent
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['TransactionEvent'], typing.List['TransactionEvent']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'events':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'TransactionEvent':
                    return super().__getitem__(i)
            
            
            class previous_block_votes_bitvec(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'previous_block_votes_bitvec':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            proposer = schemas.StrSchema
            
            
            class failed_proposer_indices(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'failed_proposer_indices':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            timestamp = schemas.StrSchema
            __annotations__ = {
                "type": type,
                "version": version,
                "hash": hash,
                "state_change_hash": state_change_hash,
                "event_root_hash": event_root_hash,
                "state_checkpoint_hash": state_checkpoint_hash,
                "gas_used": gas_used,
                "success": success,
                "vm_status": vm_status,
                "accumulator_root_hash": accumulator_root_hash,
                "changes": changes,
                "id": id,
                "epoch": epoch,
                "round": round,
                "events": events,
                "previous_block_votes_bitvec": previous_block_votes_bitvec,
                "proposer": proposer,
                "failed_proposer_indices": failed_proposer_indices,
                "timestamp": timestamp,
            }
    
    proposer: MetaOapg.properties.proposer
    event_root_hash: MetaOapg.properties.event_root_hash
    gas_used: MetaOapg.properties.gas_used
    changes: MetaOapg.properties.changes
    previous_block_votes_bitvec: MetaOapg.properties.previous_block_votes_bitvec
    state_checkpoint_hash: MetaOapg.properties.state_checkpoint_hash
    epoch: MetaOapg.properties.epoch
    state_change_hash: MetaOapg.properties.state_change_hash
    accumulator_root_hash: MetaOapg.properties.accumulator_root_hash
    type: MetaOapg.properties.type
    version: MetaOapg.properties.version
    failed_proposer_indices: MetaOapg.properties.failed_proposer_indices
    vm_status: MetaOapg.properties.vm_status
    round: MetaOapg.properties.round
    success: MetaOapg.properties.success
    id: MetaOapg.properties.id
    events: MetaOapg.properties.events
    hash: MetaOapg.properties.hash
    timestamp: MetaOapg.properties.timestamp
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["version"]) -> MetaOapg.properties.version: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["hash"]) -> MetaOapg.properties.hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["state_change_hash"]) -> MetaOapg.properties.state_change_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["event_root_hash"]) -> MetaOapg.properties.event_root_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["state_checkpoint_hash"]) -> MetaOapg.properties.state_checkpoint_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["gas_used"]) -> MetaOapg.properties.gas_used: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["success"]) -> MetaOapg.properties.success: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["vm_status"]) -> MetaOapg.properties.vm_status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["accumulator_root_hash"]) -> MetaOapg.properties.accumulator_root_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["changes"]) -> MetaOapg.properties.changes: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["epoch"]) -> MetaOapg.properties.epoch: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["round"]) -> MetaOapg.properties.round: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["events"]) -> MetaOapg.properties.events: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["previous_block_votes_bitvec"]) -> MetaOapg.properties.previous_block_votes_bitvec: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["proposer"]) -> MetaOapg.properties.proposer: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["failed_proposer_indices"]) -> MetaOapg.properties.failed_proposer_indices: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["timestamp"]) -> MetaOapg.properties.timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["type", "version", "hash", "state_change_hash", "event_root_hash", "state_checkpoint_hash", "gas_used", "success", "vm_status", "accumulator_root_hash", "changes", "id", "epoch", "round", "events", "previous_block_votes_bitvec", "proposer", "failed_proposer_indices", "timestamp", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["version"]) -> MetaOapg.properties.version: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["hash"]) -> MetaOapg.properties.hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["state_change_hash"]) -> MetaOapg.properties.state_change_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["event_root_hash"]) -> MetaOapg.properties.event_root_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["state_checkpoint_hash"]) -> MetaOapg.properties.state_checkpoint_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["gas_used"]) -> MetaOapg.properties.gas_used: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["success"]) -> MetaOapg.properties.success: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["vm_status"]) -> MetaOapg.properties.vm_status: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["accumulator_root_hash"]) -> MetaOapg.properties.accumulator_root_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["changes"]) -> MetaOapg.properties.changes: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["epoch"]) -> MetaOapg.properties.epoch: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["round"]) -> MetaOapg.properties.round: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["events"]) -> MetaOapg.properties.events: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["previous_block_votes_bitvec"]) -> MetaOapg.properties.previous_block_votes_bitvec: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["proposer"]) -> MetaOapg.properties.proposer: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["failed_proposer_indices"]) -> MetaOapg.properties.failed_proposer_indices: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["timestamp"]) -> MetaOapg.properties.timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["type", "version", "hash", "state_change_hash", "event_root_hash", "state_checkpoint_hash", "gas_used", "success", "vm_status", "accumulator_root_hash", "changes", "id", "epoch", "round", "events", "previous_block_votes_bitvec", "proposer", "failed_proposer_indices", "timestamp", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        proposer: typing.Union[MetaOapg.properties.proposer, str, ],
        event_root_hash: typing.Union[MetaOapg.properties.event_root_hash, str, ],
        gas_used: typing.Union[MetaOapg.properties.gas_used, str, ],
        changes: typing.Union[MetaOapg.properties.changes, list, tuple, ],
        previous_block_votes_bitvec: typing.Union[MetaOapg.properties.previous_block_votes_bitvec, list, tuple, ],
        state_checkpoint_hash: typing.Union[MetaOapg.properties.state_checkpoint_hash, str, ],
        epoch: typing.Union[MetaOapg.properties.epoch, str, ],
        state_change_hash: typing.Union[MetaOapg.properties.state_change_hash, str, ],
        accumulator_root_hash: typing.Union[MetaOapg.properties.accumulator_root_hash, str, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        version: typing.Union[MetaOapg.properties.version, str, ],
        failed_proposer_indices: typing.Union[MetaOapg.properties.failed_proposer_indices, list, tuple, ],
        vm_status: typing.Union[MetaOapg.properties.vm_status, str, ],
        round: typing.Union[MetaOapg.properties.round, str, ],
        success: typing.Union[MetaOapg.properties.success, bool, ],
        id: typing.Union[MetaOapg.properties.id, str, ],
        events: typing.Union[MetaOapg.properties.events, list, tuple, ],
        hash: typing.Union[MetaOapg.properties.hash, str, ],
        timestamp: typing.Union[MetaOapg.properties.timestamp, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'BlockMetadataTransaction':
        return super().__new__(
            cls,
            *args,
            proposer=proposer,
            event_root_hash=event_root_hash,
            gas_used=gas_used,
            changes=changes,
            previous_block_votes_bitvec=previous_block_votes_bitvec,
            state_checkpoint_hash=state_checkpoint_hash,
            epoch=epoch,
            state_change_hash=state_change_hash,
            accumulator_root_hash=accumulator_root_hash,
            type=type,
            version=version,
            failed_proposer_indices=failed_proposer_indices,
            vm_status=vm_status,
            round=round,
            success=success,
            id=id,
            events=events,
            hash=hash,
            timestamp=timestamp,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_aptos_api.model.transaction_event import TransactionEvent



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class AptosBlock(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "lastVersion",
            "number",
            "firstVersion",
            "hash",
            "timestamp",
        }
        
        class properties:
            lastVersion = schemas.StrSchema
            firstVersion = schemas.StrSchema
            hash = schemas.StrSchema
            timestamp = schemas.StrSchema
            number = schemas.StrSchema
            __annotations__ = {
                "lastVersion": lastVersion,
                "firstVersion": firstVersion,
                "hash": hash,
                "timestamp": timestamp,
                "number": number,
            }
    
    lastVersion: MetaOapg.properties.lastVersion
    number: MetaOapg.properties.number
    firstVersion: MetaOapg.properties.firstVersion
    hash: MetaOapg.properties.hash
    timestamp: MetaOapg.properties.timestamp
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["lastVersion"]) -> MetaOapg.properties.lastVersion: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["firstVersion"]) -> MetaOapg.properties.firstVersion: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["hash"]) -> MetaOapg.properties.hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["timestamp"]) -> MetaOapg.properties.timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["number"]) -> MetaOapg.properties.number: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["lastVersion", "firstVersion", "hash", "timestamp", "number", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["lastVersion"]) -> MetaOapg.properties.lastVersion: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["firstVersion"]) -> MetaOapg.properties.firstVersion: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["hash"]) -> MetaOapg.properties.hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["timestamp"]) -> MetaOapg.properties.timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["number"]) -> MetaOapg.properties.number: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["lastVersion", "firstVersion", "hash", "timestamp", "number", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        lastVersion: typing.Union[MetaOapg.properties.lastVersion, str, ],
        number: typing.Union[MetaOapg.properties.number, str, ],
        firstVersion: typing.Union[MetaOapg.properties.firstVersion, str, ],
        hash: typing.Union[MetaOapg.properties.hash, str, ],
        timestamp: typing.Union[MetaOapg.properties.timestamp, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'AptosBlock':
        return super().__new__(
            cls,
            *args,
            lastVersion=lastVersion,
            number=number,
            firstVersion=firstVersion,
            hash=hash,
            timestamp=timestamp,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401


class NFTTransferResponse(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "coin_amount",
            "token_data_id_hash",
            "coin_type",
            "event_sequence_number",
            "to_address",
            "transaction_timestamp",
            "event_creation_number",
            "event_account_address",
            "collection_data_id_hash",
            "name",
            "token_amount",
            "creator_address",
            "property_version",
            "transfer_type",
            "transaction_version",
            "from_address",
            "collection_name",
        }
        
        class properties:
            coin_amount = schemas.StrSchema
            coin_type = schemas.StrSchema
            
            
            class collection_data_id_hash(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 64
                    min_length = 64
            
            
            class collection_name(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 128
                    min_length = 1
            
            
            class creator_address(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 66
                    min_length = 66
            event_account_address = schemas.StrSchema
            event_creation_number = schemas.StrSchema
            event_sequence_number = schemas.StrSchema
            
            
            class from_address(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 66
                    min_length = 66
            
            
            class name(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 128
                    min_length = 1
            property_version = schemas.StrSchema
            
            
            class to_address(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 66
                    min_length = 66
            token_amount = schemas.StrSchema
            
            
            class token_data_id_hash(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 64
                    min_length = 64
            transaction_timestamp = schemas.StrSchema
            transaction_version = schemas.StrSchema
            transfer_type = schemas.StrSchema
            __annotations__ = {
                "coin_amount": coin_amount,
                "coin_type": coin_type,
                "collection_data_id_hash": collection_data_id_hash,
                "collection_name": collection_name,
                "creator_address": creator_address,
                "event_account_address": event_account_address,
                "event_creation_number": event_creation_number,
                "event_sequence_number": event_sequence_number,
                "from_address": from_address,
                "name": name,
                "property_version": property_version,
                "to_address": to_address,
                "token_amount": token_amount,
                "token_data_id_hash": token_data_id_hash,
                "transaction_timestamp": transaction_timestamp,
                "transaction_version": transaction_version,
                "transfer_type": transfer_type,
            }
    
    coin_amount: MetaOapg.properties.coin_amount
    token_data_id_hash: MetaOapg.properties.token_data_id_hash
    coin_type: MetaOapg.properties.coin_type
    event_sequence_number: MetaOapg.properties.event_sequence_number
    to_address: MetaOapg.properties.to_address
    transaction_timestamp: MetaOapg.properties.transaction_timestamp
    event_creation_number: MetaOapg.properties.event_creation_number
    event_account_address: MetaOapg.properties.event_account_address
    collection_data_id_hash: MetaOapg.properties.collection_data_id_hash
    name: MetaOapg.properties.name
    token_amount: MetaOapg.properties.token_amount
    creator_address: MetaOapg.properties.creator_address
    property_version: MetaOapg.properties.property_version
    transfer_type: MetaOapg.properties.transfer_type
    transaction_version: MetaOapg.properties.transaction_version
    from_address: MetaOapg.properties.from_address
    collection_name: MetaOapg.properties.collection_name
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["coin_amount"]) -> MetaOapg.properties.coin_amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["coin_type"]) -> MetaOapg.properties.coin_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["collection_data_id_hash"]) -> MetaOapg.properties.collection_data_id_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["collection_name"]) -> MetaOapg.properties.collection_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["creator_address"]) -> MetaOapg.properties.creator_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["event_account_address"]) -> MetaOapg.properties.event_account_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["event_creation_number"]) -> MetaOapg.properties.event_creation_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["event_sequence_number"]) -> MetaOapg.properties.event_sequence_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["from_address"]) -> MetaOapg.properties.from_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["property_version"]) -> MetaOapg.properties.property_version: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["to_address"]) -> MetaOapg.properties.to_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_amount"]) -> MetaOapg.properties.token_amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_data_id_hash"]) -> MetaOapg.properties.token_data_id_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_timestamp"]) -> MetaOapg.properties.transaction_timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_version"]) -> MetaOapg.properties.transaction_version: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transfer_type"]) -> MetaOapg.properties.transfer_type: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["coin_amount", "coin_type", "collection_data_id_hash", "collection_name", "creator_address", "event_account_address", "event_creation_number", "event_sequence_number", "from_address", "name", "property_version", "to_address", "token_amount", "token_data_id_hash", "transaction_timestamp", "transaction_version", "transfer_type", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["coin_amount"]) -> MetaOapg.properties.coin_amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["coin_type"]) -> MetaOapg.properties.coin_type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["collection_data_id_hash"]) -> MetaOapg.properties.collection_data_id_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["collection_name"]) -> MetaOapg.properties.collection_name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["creator_address"]) -> MetaOapg.properties.creator_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["event_account_address"]) -> MetaOapg.properties.event_account_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["event_creation_number"]) -> MetaOapg.properties.event_creation_number: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["event_sequence_number"]) -> MetaOapg.properties.event_sequence_number: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["from_address"]) -> MetaOapg.properties.from_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["property_version"]) -> MetaOapg.properties.property_version: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["to_address"]) -> MetaOapg.properties.to_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_amount"]) -> MetaOapg.properties.token_amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_data_id_hash"]) -> MetaOapg.properties.token_data_id_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_timestamp"]) -> MetaOapg.properties.transaction_timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_version"]) -> MetaOapg.properties.transaction_version: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transfer_type"]) -> MetaOapg.properties.transfer_type: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["coin_amount", "coin_type", "collection_data_id_hash", "collection_name", "creator_address", "event_account_address", "event_creation_number", "event_sequence_number", "from_address", "name", "property_version", "to_address", "token_amount", "token_data_id_hash", "transaction_timestamp", "transaction_version", "transfer_type", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        coin_amount: typing.Union[MetaOapg.properties.coin_amount, str, ],
        token_data_id_hash: typing.Union[MetaOapg.properties.token_data_id_hash, str, ],
        coin_type: typing.Union[MetaOapg.properties.coin_type, str, ],
        event_sequence_number: typing.Union[MetaOapg.properties.event_sequence_number, str, ],
        to_address: typing.Union[MetaOapg.properties.to_address, str, ],
        transaction_timestamp: typing.Union[MetaOapg.properties.transaction_timestamp, str, ],
        event_creation_number: typing.Union[MetaOapg.properties.event_creation_number, str, ],
        event_account_address: typing.Union[MetaOapg.properties.event_account_address, str, ],
        collection_data_id_hash: typing.Union[MetaOapg.properties.collection_data_id_hash, str, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        token_amount: typing.Union[MetaOapg.properties.token_amount, str, ],
        creator_address: typing.Union[MetaOapg.properties.creator_address, str, ],
        property_version: typing.Union[MetaOapg.properties.property_version, str, ],
        transfer_type: typing.Union[MetaOapg.properties.transfer_type, str, ],
        transaction_version: typing.Union[MetaOapg.properties.transaction_version, str, ],
        from_address: typing.Union[MetaOapg.properties.from_address, str, ],
        collection_name: typing.Union[MetaOapg.properties.collection_name, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'NFTTransferResponse':
        return super().__new__(
            cls,
            *args,
            coin_amount=coin_amount,
            token_data_id_hash=token_data_id_hash,
            coin_type=coin_type,
            event_sequence_number=event_sequence_number,
            to_address=to_address,
            transaction_timestamp=transaction_timestamp,
            event_creation_number=event_creation_number,
            event_account_address=event_account_address,
            collection_data_id_hash=collection_data_id_hash,
            name=name,
            token_amount=token_amount,
            creator_address=creator_address,
            property_version=property_version,
            transfer_type=transfer_type,
            transaction_version=transaction_version,
            from_address=from_address,
            collection_name=collection_name,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class LogEvent(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "address",
            "data",
            "block_timestamp",
            "block_hash",
            "block_number",
            "transaction_hash",
        }
        
        class properties:
            transaction_hash = schemas.StrSchema
            address = schemas.StrSchema
            block_timestamp = schemas.StrSchema
            block_number = schemas.StrSchema
            block_hash = schemas.StrSchema
            
            
            class data(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        _from = schemas.StrSchema
                        to = schemas.StrSchema
                        value = schemas.StrSchema
                        __annotations__ = {
                            "from": _from,
                            "to": to,
                            "value": value,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["from"]) -> MetaOapg.properties._from: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["to"]) -> MetaOapg.properties.to: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["from", "to", "value", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["from"]) -> typing.Union[MetaOapg.properties._from, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["to"]) -> typing.Union[MetaOapg.properties.to, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> typing.Union[MetaOapg.properties.value, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["from", "to", "value", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    to: typing.Union[MetaOapg.properties.to, str, schemas.Unset] = schemas.unset,
                    value: typing.Union[MetaOapg.properties.value, str, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'data':
                    return super().__new__(
                        cls,
                        *args,
                        to=to,
                        value=value,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "transaction_hash": transaction_hash,
                "address": address,
                "block_timestamp": block_timestamp,
                "block_number": block_number,
                "block_hash": block_hash,
                "data": data,
            }

    
    address: MetaOapg.properties.address
    data: MetaOapg.properties.data
    block_timestamp: MetaOapg.properties.block_timestamp
    block_hash: MetaOapg.properties.block_hash
    block_number: MetaOapg.properties.block_number
    transaction_hash: MetaOapg.properties.transaction_hash
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_hash"]) -> MetaOapg.properties.transaction_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_hash"]) -> MetaOapg.properties.block_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["transaction_hash", "address", "block_timestamp", "block_number", "block_hash", "data", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_hash"]) -> MetaOapg.properties.transaction_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_hash"]) -> MetaOapg.properties.block_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["transaction_hash", "address", "block_timestamp", "block_number", "block_hash", "data", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        address: typing.Union[MetaOapg.properties.address, str, ],
        data: typing.Union[MetaOapg.properties.data, dict, frozendict.frozendict, ],
        block_timestamp: typing.Union[MetaOapg.properties.block_timestamp, str, ],
        block_hash: typing.Union[MetaOapg.properties.block_hash, str, ],
        block_number: typing.Union[MetaOapg.properties.block_number, str, ],
        transaction_hash: typing.Union[MetaOapg.properties.transaction_hash, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'LogEvent':
        return super().__new__(
            cls,
            *args,
            address=address,
            data=data,
            block_timestamp=block_timestamp,
            block_hash=block_hash,
            block_number=block_number,
            transaction_hash=transaction_hash,
            _configuration=_configuration,
            **kwargs,
        )



import openapi_aptos_api
from openapi_aptos_api.apis.tags import collections_api
from ..utilities import get_common_headers

hosts = {
    "mainnet": "https://mainnet-aptos-api.moralis.io",
    "testnet": "https://testnet-aptos-api.moralis.io",
    }

def get_host_url(params = None):
    if params is not None and "network" in params:
        if params["network"] in hosts:
            return hosts[params["network"]]
        else:
            raise Exception('Unknown value provided for .')
    return hosts["mainnet"]


def get_api_instance(api_key, params = None):
    configuration = openapi_aptos_api.Configuration()
    configuration.host = get_host_url(params)
    configuration.access_token = api_key
    api_client = openapi_aptos_api.ApiClient(configuration)
    headers = get_common_headers()
    for header in headers:
        api_client.default_headers[header] = headers[header]
    api_instance = collections_api.CollectionsApi(api_client)
    api_client.close()

    return api_instance



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from openapi_auth.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    CHALLENGE_REQUEST_EVM = "/challenge/request/evm"
    CHALLENGE_VERIFY_EVM = "/challenge/verify/evm"
    CHALLENGE_REQUEST_SOLANA = "/challenge/request/solana"
    CHALLENGE_VERIFY_SOLANA = "/challenge/verify/solana"
    CHALLENGE_REQUEST_APTOS = "/challenge/request/aptos"
    CHALLENGE_VERIFY_APTOS = "/challenge/verify/aptos"
    PROFILE_PROFILE_ID_ADDRESSES = "/profile/{profileId}/addresses"
    BIND_REQUEST = "/bind/request"
    BIND_REQUEST_VERIFY = "/bind/request/verify"
    BIND_REMOVE = "/bind/remove"
    BIND_REMOVE_VERIFY = "/bind/remove/verify"



# coding: utf-8

"""
    Solana API

    Moralis Solana API  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_sol_api import schemas  # noqa: F401


class NFTMetadata(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "standard",
            "mint",
            "symbol",
            "metaplex",
            "name",
        }
        
        class properties:
            mint = schemas.StrSchema
            standard = schemas.StrSchema
            name = schemas.StrSchema
            symbol = schemas.StrSchema
        
            @staticmethod
            def metaplex() -> typing.Type['MetaplexNFT']:
                return MetaplexNFT
            __annotations__ = {
                "mint": mint,
                "standard": standard,
                "name": name,
                "symbol": symbol,
                "metaplex": metaplex,
            }
    
    standard: MetaOapg.properties.standard
    mint: MetaOapg.properties.mint
    symbol: MetaOapg.properties.symbol
    metaplex: 'MetaplexNFT'
    name: MetaOapg.properties.name
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["mint"]) -> MetaOapg.properties.mint: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["standard"]) -> MetaOapg.properties.standard: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["symbol"]) -> MetaOapg.properties.symbol: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metaplex"]) -> 'MetaplexNFT': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["mint", "standard", "name", "symbol", "metaplex", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["mint"]) -> MetaOapg.properties.mint: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["standard"]) -> MetaOapg.properties.standard: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["symbol"]) -> MetaOapg.properties.symbol: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metaplex"]) -> 'MetaplexNFT': ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["mint", "standard", "name", "symbol", "metaplex", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        standard: typing.Union[MetaOapg.properties.standard, str, ],
        mint: typing.Union[MetaOapg.properties.mint, str, ],
        symbol: typing.Union[MetaOapg.properties.symbol, str, ],
        metaplex: 'MetaplexNFT',
        name: typing.Union[MetaOapg.properties.name, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'NFTMetadata':
        return super().__new__(
            cls,
            *args,
            standard=standard,
            mint=mint,
            symbol=symbol,
            metaplex=metaplex,
            name=name,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_sol_api.model.metaplex_nft import MetaplexNFT



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class EndpointWeights(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "path",
            "endpoint",
            "price",
            "rateLimitCost",
        }
        
        class properties:
            endpoint = schemas.StrSchema
            path = schemas.StrSchema
            rateLimitCost = schemas.StrSchema
            price = schemas.StrSchema
            __annotations__ = {
                "endpoint": endpoint,
                "path": path,
                "rateLimitCost": rateLimitCost,
                "price": price,
            }

    
    path: MetaOapg.properties.path
    endpoint: MetaOapg.properties.endpoint
    price: MetaOapg.properties.price
    rateLimitCost: MetaOapg.properties.rateLimitCost
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["endpoint"]) -> MetaOapg.properties.endpoint: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["path"]) -> MetaOapg.properties.path: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["rateLimitCost"]) -> MetaOapg.properties.rateLimitCost: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["price"]) -> MetaOapg.properties.price: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["endpoint", "path", "rateLimitCost", "price", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["endpoint"]) -> MetaOapg.properties.endpoint: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["path"]) -> MetaOapg.properties.path: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["rateLimitCost"]) -> MetaOapg.properties.rateLimitCost: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["price"]) -> MetaOapg.properties.price: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["endpoint", "path", "rateLimitCost", "price", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        path: typing.Union[MetaOapg.properties.path, str, ],
        endpoint: typing.Union[MetaOapg.properties.endpoint, str, ],
        price: typing.Union[MetaOapg.properties.price, str, ],
        rateLimitCost: typing.Union[MetaOapg.properties.rateLimitCost, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'EndpointWeights':
        return super().__new__(
            cls,
            *args,
            path=path,
            endpoint=endpoint,
            price=price,
            rateLimitCost=rateLimitCost,
            _configuration=_configuration,
            **kwargs,
        )



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from openapi_aptos_api.paths.accounts_address_resource_module_name import Api

from openapi_aptos_api.paths import PathValues

path = PathValues.ACCOUNTS_ADDRESS_RESOURCE_MODULE_NAME


# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from openapi_aptos_api.paths.nfts_collections_collection_data_id_hash_tokens import Api

from openapi_aptos_api.paths import PathValues

path = PathValues.NFTS_COLLECTIONS_COLLECTION_DATA_ID_HASH_TOKENS


# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401


class NFTOwnerResponse(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "last_transaction_version",
            "amount",
            "last_transaction_timestamp",
            "token_data_id_hash",
            "collection_data_id_hash",
            "name",
            "token_properties",
            "creator_address",
            "owner_address",
            "property_version",
            "collection_name",
            "table_type",
        }
        
        class properties:
            amount = schemas.StrSchema
            
            
            class collection_data_id_hash(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 64
                    min_length = 64
            
            
            class collection_name(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 128
                    min_length = 1
            
            
            class creator_address(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 66
                    min_length = 66
            last_transaction_timestamp = schemas.StrSchema
            last_transaction_version = schemas.StrSchema
            
            
            class name(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 128
                    min_length = 1
            
            
            class owner_address(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 66
                    min_length = 66
            property_version = schemas.StrSchema
            table_type = schemas.StrSchema
            
            
            class token_data_id_hash(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 64
                    min_length = 64
            
            
            class token_properties(
                schemas.DictBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneFrozenDictMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, None, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'token_properties':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "amount": amount,
                "collection_data_id_hash": collection_data_id_hash,
                "collection_name": collection_name,
                "creator_address": creator_address,
                "last_transaction_timestamp": last_transaction_timestamp,
                "last_transaction_version": last_transaction_version,
                "name": name,
                "owner_address": owner_address,
                "property_version": property_version,
                "table_type": table_type,
                "token_data_id_hash": token_data_id_hash,
                "token_properties": token_properties,
            }
    
    last_transaction_version: MetaOapg.properties.last_transaction_version
    amount: MetaOapg.properties.amount
    last_transaction_timestamp: MetaOapg.properties.last_transaction_timestamp
    token_data_id_hash: MetaOapg.properties.token_data_id_hash
    collection_data_id_hash: MetaOapg.properties.collection_data_id_hash
    name: MetaOapg.properties.name
    token_properties: MetaOapg.properties.token_properties
    creator_address: MetaOapg.properties.creator_address
    owner_address: MetaOapg.properties.owner_address
    property_version: MetaOapg.properties.property_version
    collection_name: MetaOapg.properties.collection_name
    table_type: MetaOapg.properties.table_type
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["collection_data_id_hash"]) -> MetaOapg.properties.collection_data_id_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["collection_name"]) -> MetaOapg.properties.collection_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["creator_address"]) -> MetaOapg.properties.creator_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_transaction_timestamp"]) -> MetaOapg.properties.last_transaction_timestamp: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["last_transaction_version"]) -> MetaOapg.properties.last_transaction_version: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["owner_address"]) -> MetaOapg.properties.owner_address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["property_version"]) -> MetaOapg.properties.property_version: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["table_type"]) -> MetaOapg.properties.table_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_data_id_hash"]) -> MetaOapg.properties.token_data_id_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_properties"]) -> MetaOapg.properties.token_properties: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["amount", "collection_data_id_hash", "collection_name", "creator_address", "last_transaction_timestamp", "last_transaction_version", "name", "owner_address", "property_version", "table_type", "token_data_id_hash", "token_properties", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> MetaOapg.properties.amount: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["collection_data_id_hash"]) -> MetaOapg.properties.collection_data_id_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["collection_name"]) -> MetaOapg.properties.collection_name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["creator_address"]) -> MetaOapg.properties.creator_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_transaction_timestamp"]) -> MetaOapg.properties.last_transaction_timestamp: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["last_transaction_version"]) -> MetaOapg.properties.last_transaction_version: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["owner_address"]) -> MetaOapg.properties.owner_address: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["property_version"]) -> MetaOapg.properties.property_version: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["table_type"]) -> MetaOapg.properties.table_type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_data_id_hash"]) -> MetaOapg.properties.token_data_id_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_properties"]) -> MetaOapg.properties.token_properties: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["amount", "collection_data_id_hash", "collection_name", "creator_address", "last_transaction_timestamp", "last_transaction_version", "name", "owner_address", "property_version", "table_type", "token_data_id_hash", "token_properties", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        last_transaction_version: typing.Union[MetaOapg.properties.last_transaction_version, str, ],
        amount: typing.Union[MetaOapg.properties.amount, str, ],
        last_transaction_timestamp: typing.Union[MetaOapg.properties.last_transaction_timestamp, str, ],
        token_data_id_hash: typing.Union[MetaOapg.properties.token_data_id_hash, str, ],
        collection_data_id_hash: typing.Union[MetaOapg.properties.collection_data_id_hash, str, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        token_properties: typing.Union[MetaOapg.properties.token_properties, dict, frozendict.frozendict, None, ],
        creator_address: typing.Union[MetaOapg.properties.creator_address, str, ],
        owner_address: typing.Union[MetaOapg.properties.owner_address, str, ],
        property_version: typing.Union[MetaOapg.properties.property_version, str, ],
        collection_name: typing.Union[MetaOapg.properties.collection_name, str, ],
        table_type: typing.Union[MetaOapg.properties.table_type, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'NFTOwnerResponse':
        return super().__new__(
            cls,
            *args,
            last_transaction_version=last_transaction_version,
            amount=amount,
            last_transaction_timestamp=last_transaction_timestamp,
            token_data_id_hash=token_data_id_hash,
            collection_data_id_hash=collection_data_id_hash,
            name=name,
            token_properties=token_properties,
            creator_address=creator_address,
            owner_address=owner_address,
            property_version=property_version,
            collection_name=collection_name,
            table_type=table_type,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from openapi_aptos_api.paths.transactions_encode_submission.post import EncodeSubmission
from openapi_aptos_api.paths.accounts_address_transactions.get import GetAccountTransactions
from openapi_aptos_api.paths.blocks_block_height.get import GetBlockByHeight
from openapi_aptos_api.paths.blocks_by_version_version.get import GetBlockByVersion
from openapi_aptos_api.paths.transactions_by_hash_txn_hash.get import GetTransactionByHash
from openapi_aptos_api.paths.transactions_by_version_txn_version.get import GetTransactionByVersion
from openapi_aptos_api.paths.transactions.get import GetTransactions
from openapi_aptos_api.paths.transactions_simulate.post import SimulateTransaction
from openapi_aptos_api.paths.transactions_batch.post import SubmitBatchTransactions
from openapi_aptos_api.paths.transactions.post import SubmitTransaction


class DefaultApi(
    EncodeSubmission,
    GetAccountTransactions,
    GetBlockByHeight,
    GetBlockByVersion,
    GetTransactionByHash,
    GetTransactionByVersion,
    GetTransactions,
    SimulateTransaction,
    SubmitBatchTransactions,
    SubmitTransaction,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class AptosCreateStreamType(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "description",
            "tag",
            "webhookUrl",
            "network",
        }
        
        class properties:
            webhookUrl = schemas.StrSchema
            tag = schemas.StrSchema
        
            @staticmethod
            def network() -> typing.Type['AptosNetwork']:
                return AptosNetwork
            description = schemas.StrSchema
            
            
            class functions(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'functions':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            
            
            class events(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'events':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            includePayload = schemas.BoolSchema
            includeEvents = schemas.BoolSchema
            includeChanges = schemas.BoolSchema
            demo = schemas.BoolSchema
            allAddresses = schemas.BoolSchema
            __annotations__ = {
                "webhookUrl": webhookUrl,
                "tag": tag,
                "network": network,
                "description": description,
                "functions": functions,
                "events": events,
                "includePayload": includePayload,
                "includeEvents": includeEvents,
                "includeChanges": includeChanges,
                "demo": demo,
                "allAddresses": allAddresses,
            }
    
    description: MetaOapg.properties.description
    tag: MetaOapg.properties.tag
    webhookUrl: MetaOapg.properties.webhookUrl
    network: 'AptosNetwork'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["webhookUrl"]) -> MetaOapg.properties.webhookUrl: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tag"]) -> MetaOapg.properties.tag: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["network"]) -> 'AptosNetwork': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["functions"]) -> MetaOapg.properties.functions: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["events"]) -> MetaOapg.properties.events: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["includePayload"]) -> MetaOapg.properties.includePayload: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["includeEvents"]) -> MetaOapg.properties.includeEvents: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["includeChanges"]) -> MetaOapg.properties.includeChanges: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["demo"]) -> MetaOapg.properties.demo: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["allAddresses"]) -> MetaOapg.properties.allAddresses: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["webhookUrl", "tag", "network", "description", "functions", "events", "includePayload", "includeEvents", "includeChanges", "demo", "allAddresses", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["webhookUrl"]) -> MetaOapg.properties.webhookUrl: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tag"]) -> MetaOapg.properties.tag: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["network"]) -> 'AptosNetwork': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["functions"]) -> typing.Union[MetaOapg.properties.functions, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["events"]) -> typing.Union[MetaOapg.properties.events, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["includePayload"]) -> typing.Union[MetaOapg.properties.includePayload, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["includeEvents"]) -> typing.Union[MetaOapg.properties.includeEvents, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["includeChanges"]) -> typing.Union[MetaOapg.properties.includeChanges, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["demo"]) -> typing.Union[MetaOapg.properties.demo, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["allAddresses"]) -> typing.Union[MetaOapg.properties.allAddresses, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["webhookUrl", "tag", "network", "description", "functions", "events", "includePayload", "includeEvents", "includeChanges", "demo", "allAddresses", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        description: typing.Union[MetaOapg.properties.description, str, ],
        tag: typing.Union[MetaOapg.properties.tag, str, ],
        webhookUrl: typing.Union[MetaOapg.properties.webhookUrl, str, ],
        network: 'AptosNetwork',
        functions: typing.Union[MetaOapg.properties.functions, list, tuple, schemas.Unset] = schemas.unset,
        events: typing.Union[MetaOapg.properties.events, list, tuple, schemas.Unset] = schemas.unset,
        includePayload: typing.Union[MetaOapg.properties.includePayload, bool, schemas.Unset] = schemas.unset,
        includeEvents: typing.Union[MetaOapg.properties.includeEvents, bool, schemas.Unset] = schemas.unset,
        includeChanges: typing.Union[MetaOapg.properties.includeChanges, bool, schemas.Unset] = schemas.unset,
        demo: typing.Union[MetaOapg.properties.demo, bool, schemas.Unset] = schemas.unset,
        allAddresses: typing.Union[MetaOapg.properties.allAddresses, bool, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'AptosCreateStreamType':
        return super().__new__(
            cls,
            *args,
            description=description,
            tag=tag,
            webhookUrl=webhookUrl,
            network=network,
            functions=functions,
            events=events,
            includePayload=includePayload,
            includeEvents=includeEvents,
            includeChanges=includeChanges,
            demo=demo,
            allAddresses=allAddresses,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_streams.model.aptos_network import AptosNetwork



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class AptosTransaction(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "gasLimit",
            "gasUsed",
            "eventChangeHash",
            "sender",
            "success",
            "stateChangeHash",
            "gasUnitPrice",
            "type",
            "hash",
        }
        
        class properties:
            gasUnitPrice = schemas.StrSchema
            type = schemas.StrSchema
            gasUsed = schemas.StrSchema
            eventChangeHash = schemas.StrSchema
            stateChangeHash = schemas.StrSchema
            gasLimit = schemas.StrSchema
            sender = schemas.StrSchema
            success = schemas.BoolSchema
            hash = schemas.StrSchema
            __annotations__ = {
                "gasUnitPrice": gasUnitPrice,
                "type": type,
                "gasUsed": gasUsed,
                "eventChangeHash": eventChangeHash,
                "stateChangeHash": stateChangeHash,
                "gasLimit": gasLimit,
                "sender": sender,
                "success": success,
                "hash": hash,
            }
    
    gasLimit: MetaOapg.properties.gasLimit
    gasUsed: MetaOapg.properties.gasUsed
    eventChangeHash: MetaOapg.properties.eventChangeHash
    sender: MetaOapg.properties.sender
    success: MetaOapg.properties.success
    stateChangeHash: MetaOapg.properties.stateChangeHash
    gasUnitPrice: MetaOapg.properties.gasUnitPrice
    type: MetaOapg.properties.type
    hash: MetaOapg.properties.hash
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["gasUnitPrice"]) -> MetaOapg.properties.gasUnitPrice: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["gasUsed"]) -> MetaOapg.properties.gasUsed: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["eventChangeHash"]) -> MetaOapg.properties.eventChangeHash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["stateChangeHash"]) -> MetaOapg.properties.stateChangeHash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["gasLimit"]) -> MetaOapg.properties.gasLimit: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sender"]) -> MetaOapg.properties.sender: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["success"]) -> MetaOapg.properties.success: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["hash"]) -> MetaOapg.properties.hash: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["gasUnitPrice", "type", "gasUsed", "eventChangeHash", "stateChangeHash", "gasLimit", "sender", "success", "hash", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["gasUnitPrice"]) -> MetaOapg.properties.gasUnitPrice: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["gasUsed"]) -> MetaOapg.properties.gasUsed: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["eventChangeHash"]) -> MetaOapg.properties.eventChangeHash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["stateChangeHash"]) -> MetaOapg.properties.stateChangeHash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["gasLimit"]) -> MetaOapg.properties.gasLimit: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sender"]) -> MetaOapg.properties.sender: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["success"]) -> MetaOapg.properties.success: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["hash"]) -> MetaOapg.properties.hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["gasUnitPrice", "type", "gasUsed", "eventChangeHash", "stateChangeHash", "gasLimit", "sender", "success", "hash", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        gasLimit: typing.Union[MetaOapg.properties.gasLimit, str, ],
        gasUsed: typing.Union[MetaOapg.properties.gasUsed, str, ],
        eventChangeHash: typing.Union[MetaOapg.properties.eventChangeHash, str, ],
        sender: typing.Union[MetaOapg.properties.sender, str, ],
        success: typing.Union[MetaOapg.properties.success, bool, ],
        stateChangeHash: typing.Union[MetaOapg.properties.stateChangeHash, str, ],
        gasUnitPrice: typing.Union[MetaOapg.properties.gasUnitPrice, str, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        hash: typing.Union[MetaOapg.properties.hash, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'AptosTransaction':
        return super().__new__(
            cls,
            *args,
            gasLimit=gasLimit,
            gasUsed=gasUsed,
            eventChangeHash=eventChangeHash,
            sender=sender,
            success=success,
            stateChangeHash=stateChangeHash,
            gasUnitPrice=gasUnitPrice,
            type=type,
            hash=hash,
            _configuration=_configuration,
            **kwargs,
        )



import json
import typing
import typing_extensions
from .api_instance import get_api_instance
from openapi_auth.paths.challenge_request_solana.post import SchemaForRequestBodyApplicationJson







def request_challenge_solana(api_key: str, body: SchemaForRequestBodyApplicationJson):
    api_instance = get_api_instance(api_key)
    api_response = api_instance.request_challenge_solana(
        body=body,
        accept_content_types=(
            'application/json; charset=utf-8',
        ),
        skip_deserialization=True
    )

    return json.loads(api_response.response.data)



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class StreamsStatus(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    The stream status:
[active] The Stream is healthy and processing blocks
[paused] The Stream is paused and is not processing blocks
[error] The Stream has encountered an error and is not processing blocks
    """


    class MetaOapg:
        enum_value_to_name = {
            "active": "ACTIVE",
            "paused": "PAUSED",
            "error": "ERROR",
            "terminated": "TERMINATED",
        }
    
    @schemas.classproperty
    def ACTIVE(cls):
        return cls("active")
    
    @schemas.classproperty
    def PAUSED(cls):
        return cls("paused")
    
    @schemas.classproperty
    def ERROR(cls):
        return cls("error")
    
    @schemas.classproperty
    def TERMINATED(cls):
        return cls("terminated")
